# PRIME
[![DOI](https://zenodo.org/badge/648224321.svg)](https://zenodo.org/badge/latestdoi/648224321)

PRIME (Probabilistic Regressor for Input to the Magnetosphere Estimation) is a probabilistic algorithm that uses solar wind time history from L1 monitors to generate predictions of near-Earth solar wind with uncertainties.

INSERT USAGE STATEMENTS AND LINK TO DOCUMENTATION

For information on PRIME, including results from its validation and caveats on its use, please see the [paper](https://www.frontiersin.org/articles/10.3389/fspas.2023.1250779/full).

If you make use of PRIME, please cite it:
```
@article{obrien_prime_2023,
	title = {{PRIME}: a probabilistic neural network approach to solar wind propagation from {L1}},
	volume = {10},
	issn = {2296-987X},
	shorttitle = {{PRIME}},
	url = {https://www.frontiersin.org/articles/10.3389/fspas.2023.1250779/full},
	doi = {10.3389/fspas.2023.1250779},
	urldate = {2023-11-13},
	journal = {Frontiers in Astronomy and Space Sciences},
	author = {O’Brien, Connor and Walsh, Brian M. and Zou, Ying and Tasnim, Samira and Zhang, Huaming and Sibeck, David Gary},
	month = sep,
	year = {2023},
	pages = {1250779},
}
```